@@ -53,7 +53,6 @@ finalize (GObject *object)
 	painter = HTML_PAINTER (object);
 	html_font_manager_finalize (&painter->font_manager);
 
-	html_colorset_destroy (painter->color_set);
 	g_free (painter->font_face);
 
 	/* FIXME ownership of the color set?  */
@@ -117,8 +116,6 @@ html_painter_init (GObject *object, HTMLPainterClass *real_klass)
 	HTMLPainter *painter;
 
 	painter = HTML_PAINTER (object);
-	painter->color_set = html_colorset_new (NULL);
-
 	html_font_manager_init (&painter->font_manager, painter);
 	painter->font_style = GTK_HTML_FONT_STYLE_DEFAULT;
 	painter->font_face = NULL;
